import { LinesAndColumns } from "lines-and-columns";
export class Stylesheet {
    classIndex;
    variablesIndex;
    constructor(source) {
        const stylesheet = new LinesAndColumns(source);
        this.classIndex = new Map([...source.matchAll(/\.(?<className>[\w-]+)\s+{/g)]
            .filter(match => match.index != null)
            .map(match => {
            const location = stylesheet.locationForIndex(match.index) ?? undefined;
            if (location != null) {
                location.line = location.line + 1;
            }
            return [match.groups?.className, location];
        }));
        // To make sure we don't catch Sass variable declartions, we only look between :export {}
        this.variablesIndex = new Map([
            ...source.matchAll(/(?<=:export\s*{[^}]*)(?<key>[^\s:}]+):\s*(?<value>.*?);(?=.*})/gs),
        ]
            .filter(match => match.index != null)
            .map(match => {
            const location = stylesheet.locationForIndex(match.index) ?? undefined;
            if (location != null) {
                location.line = location.line + 1;
            }
            return [match.groups?.variableName, location];
        }));
    }
    findClass(className) {
        return this.classIndex.get(className);
    }
    findVariable(variableName) {
        return this.variablesIndex.get(variableName);
    }
}
